@@ -21,6 +21,7 @@
 #include <QActionGroup>
 #include <QMoveEvent>
 #include <QResizeEvent>
+#include <QGraphicsOpacityEffect>
 
 Item::Item(QWidget *parent) :
     QWidget(parent),
@@ -48,6 +49,41 @@ void Item::setY(int y) {
     }
 }
 
+qreal Item::opacity() const {
+    if (QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect())) {
+        return effect->opacity();
+    }
+
+    return 1.0;
+}
+
+void Item::setOpacity(qreal opacity) {
+    QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect());
+
+    if (!effect) {
+        effect = new QGraphicsOpacityEffect(this);
+        this->setGraphicsEffect(effect);
+    }
+
+    if (opacity != effect->opacity()) {
+        effect->setOpacity(opacity);
+        emit opacityChanged();
+    }
+}
+
+void Item::setFocus(bool focus) {
+    Q_D(const Item);
+
+    if ((d->complete) && (focus != this->hasFocus())) {
+        if (focus) {
+            this->setFocus(Qt::OtherFocusReason);
+        }
+        else {
+            this->clearFocus();
+        }
+    }
+}
+
 AnchorLine Item::left() const {
     Q_D(const Item);
 
@@ -120,6 +156,26 @@ void Item::resizeEvent(QResizeEvent *event) {
     QWidget::resizeEvent(event);
 }
 
+void Item::showEvent(QShowEvent *event) {
+    emit visibleChanged();
+    QWidget::showEvent(event);
+}
+
+void Item::hideEvent(QHideEvent *event) {
+    emit visibleChanged();
+    QWidget::hideEvent(event);
+}
+
+void Item::focusInEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QWidget::focusInEvent(event);
+}
+
+void Item::focusOutEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QWidget::focusOutEvent(event);
+}
+
 void Item::keyPressEvent(QKeyEvent *event) {
     Q_D(Item);
 
@@ -177,6 +233,21 @@ void ItemPrivate::data_append(QDeclarativeListProperty<QObject> *list, QObject *
 
     if (Item *item = qobject_cast<Item*>(list->object)) {
         item->d_func()->dataList.append(obj);
+
+        if (obj->isWidgetType()) {
+            item->d_func()->childrenList.append(qobject_cast<QWidget*>(obj));
+        }
+    }
+}
+
+void ItemPrivate::children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget) {
+    if (!widget) {
+        return;
+    }
+
+    if (Item *item = qobject_cast<Item*>(list->object)) {
+        item->d_func()->childrenList.append(widget);
+        item->d_func()->dataList.append(widget);
     }
 }
 
@@ -187,6 +258,7 @@ void ItemPrivate::actions_append(QDeclarativeListProperty<QObject> *list, QObjec
 
     if (Item *item = qobject_cast<Item*>(list->object)) {
         item->d_func()->actionList.append(obj);
+        item->d_func()->dataList.append(obj);
 
         if (!item->d_func()->complete) {
             return;
@@ -225,6 +297,10 @@ QDeclarativeListProperty<QObject> ItemPrivate::data() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, ItemPrivate::data_append);
 }
 
+QDeclarativeListProperty<QWidget> ItemPrivate::children() {
+    return QDeclarativeListProperty<QWidget>(q_func(), 0, ItemPrivate::children_append);
+}
+
 QDeclarativeListProperty<QObject> ItemPrivate::actions() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, ItemPrivate::actions_append);
 }
