@@ -25,6 +25,7 @@
 #include <QDeclarativeEngine>
 #include <QDeclarativeComponent>
 #include <qdeclarative.h>
+#include <QGraphicsOpacityEffect>
 
 ListView::ListView(QWidget *parent) :
     QListView(parent),
@@ -56,6 +57,41 @@ void ListView::setY(int y) {
     }
 }
 
+qreal ListView::opacity() const {
+    if (QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect())) {
+        return effect->opacity();
+    }
+
+    return 1.0;
+}
+
+void ListView::setOpacity(qreal opacity) {
+    QGraphicsOpacityEffect *effect = qobject_cast<QGraphicsOpacityEffect*>(this->graphicsEffect());
+
+    if (!effect) {
+        effect = new QGraphicsOpacityEffect(this);
+        this->setGraphicsEffect(effect);
+    }
+
+    if (opacity != effect->opacity()) {
+        effect->setOpacity(opacity);
+        emit opacityChanged();
+    }
+}
+
+void ListView::setFocus(bool focus) {
+    Q_D(const ListView);
+
+    if ((d->complete) && (focus != this->hasFocus())) {
+        if (focus) {
+            this->setFocus(Qt::OtherFocusReason);
+        }
+        else {
+            this->clearFocus();
+        }
+    }
+}
+
 AnchorLine ListView::left() const {
     Q_D(const ListView);
 
@@ -236,6 +272,26 @@ void ListView::resizeEvent(QResizeEvent *event) {
     QListView::resizeEvent(event);
 }
 
+void ListView::showEvent(QShowEvent *event) {
+    emit visibleChanged();
+    QListView::showEvent(event);
+}
+
+void ListView::hideEvent(QHideEvent *event) {
+    emit visibleChanged();
+    QListView::hideEvent(event);
+}
+
+void ListView::focusInEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QListView::focusInEvent(event);
+}
+
+void ListView::focusOutEvent(QFocusEvent *event) {
+    emit focusChanged();
+    QListView::focusOutEvent(event);
+}
+
 void ListView::rowsInserted(const QModelIndex &parent, int start, int end) {
     QListView::rowsInserted(parent, start, end);
 }
@@ -267,6 +323,21 @@ void ListViewPrivate::data_append(QDeclarativeListProperty<QObject> *list, QObje
 
     if (ListView *view = qobject_cast<ListView*>(list->object)) {
         view->d_func()->dataList.append(obj);
+
+        if (obj->isWidgetType()) {
+            view->d_func()->childrenList.append(qobject_cast<QWidget*>(obj));
+        }
+    }
+}
+
+void ListViewPrivate::children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget) {
+    if (!widget) {
+        return;
+    }
+
+    if (ListView *view = qobject_cast<ListView*>(list->object)) {
+        view->d_func()->childrenList.append(widget);
+        view->d_func()->dataList.append(widget);
     }
 }
 
@@ -277,6 +348,7 @@ void ListViewPrivate::actions_append(QDeclarativeListProperty<QObject> *list, QO
 
     if (ListView *view = qobject_cast<ListView*>(list->object)) {
         view->d_func()->actionList.append(obj);
+        view->d_func()->dataList.append(obj);
 
         if (!view->d_func()->complete) {
             return;
@@ -295,6 +367,10 @@ QDeclarativeListProperty<QObject> ListViewPrivate::data() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, ListViewPrivate::data_append);
 }
 
+QDeclarativeListProperty<QWidget> ListViewPrivate::children() {
+    return QDeclarativeListProperty<QWidget>(q_func(), 0, ListViewPrivate::children_append);
+}
+
 QDeclarativeListProperty<QObject> ListViewPrivate::actions() {
     return QDeclarativeListProperty<QObject>(q_func(), 0, ListViewPrivate::actions_append);
 }
