@@ -35,6 +35,8 @@ class ListView : public QListView, public QDeclarativeParserStatus
     Q_PROPERTY(int y READ y WRITE setY NOTIFY yChanged)
     Q_PROPERTY(int width READ width WRITE setFixedWidth NOTIFY widthChanged)
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
+    Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
+    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
     Q_PRIVATE_PROPERTY(ListView::d_func(), Anchors* anchors READ anchors CONSTANT FINAL)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
@@ -43,7 +45,7 @@ class ListView : public QListView, public QDeclarativeParserStatus
     Q_PROPERTY(AnchorLine horizontalCenter READ horizontalCenter CONSTANT FINAL)
     Q_PROPERTY(AnchorLine verticalCenter READ verticalCenter CONSTANT FINAL)
     Q_PROPERTY(bool interactive READ interactive WRITE setInteractive NOTIFY interactiveChanged)
-    Q_PROPERTY(bool moving READ moving)
+    Q_PROPERTY(bool moving READ moving NOTIFY movingChanged)
     Q_PROPERTY(bool atXBeginning READ atXBeginning NOTIFY contentXChanged)
     Q_PROPERTY(bool atXEnd READ atXEnd NOTIFY contentXChanged)
     Q_PROPERTY(bool atYBeginning READ atYBeginning NOTIFY contentYChanged)
@@ -51,8 +53,9 @@ class ListView : public QListView, public QDeclarativeParserStatus
     Q_PROPERTY(int contentX READ contentX WRITE setContentX NOTIFY contentXChanged)
     Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QObject> data READ data)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
-    Q_PRIVATE_PROPERTY(ListView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible)
+    Q_PRIVATE_PROPERTY(ListView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant model READ model WRITE setModel)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant rootIndex READ rootIndex WRITE setRootIndex)
     Q_PRIVATE_PROPERTY(ListView::d_func(), QVariant currentIndex READ currentIndex WRITE setCurrentIndex)
@@ -69,6 +72,11 @@ public:
     void setX(int x);
     void setY(int y);
 
+    qreal opacity() const;
+    void setOpacity(qreal opacity);
+
+    void setFocus(bool focus);
+
     AnchorLine left() const;
     AnchorLine right() const;
     AnchorLine top() const;
@@ -111,6 +119,9 @@ signals:
     void yChanged();
     void widthChanged();
     void heightChanged();
+    void opacityChanged();
+    void visibleChanged();
+    void focusChanged();
     void interactiveChanged();
     void movingChanged();
     void contentXChanged();
@@ -128,6 +139,10 @@ protected:
     void changeEvent(QEvent *event);
     void moveEvent(QMoveEvent *event);
     void resizeEvent(QResizeEvent *event);
+    void showEvent(QShowEvent *event);
+    void hideEvent(QHideEvent *event);
+    void focusInEvent(QFocusEvent *event);
+    void focusOutEvent(QFocusEvent *event);
 
     void classBegin();
     void componentComplete();
