@@ -45,6 +45,8 @@
 #include "menu_p.h"
 #include "mousearea_p.h"
 #include "multilistselector_p.h"
+#include "page_p.h"
+#include "pagestack_p.h"
 #include "platformstyle_p.h"
 #include "progressbar_p.h"
 #include "radiobutton_p.h"
@@ -65,7 +67,6 @@
 #include "valuebutton_p.h"
 #include "valueselector_p.h"
 #include "window_p.h"
-#include "windowstack_p_p.h"
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
 
@@ -77,16 +78,14 @@ void Plugin::initializeEngine(QDeclarativeEngine *engine, const char *uri) {
     if (engine->rootContext()->contextProperty("platformStyle").isNull()) {
         engine->rootContext()->setContextProperty("platformStyle", new PlatformStyle(engine));
         engine->rootContext()->setContextProperty("screen", new Screen(engine));
-        engine->rootContext()->setContextProperty("windowStack", new WindowStack(engine));
 
         engine->addImageProvider("theme", new ThemeImageProvider);
 
         engine->setContextForObject(Screen::instance(), engine->rootContext());
-        engine->setContextForObject(WindowStack::instance(), engine->rootContext());
 
         qmlRegisterUncreatableType<PlatformStyle>(uri, 1, 0, "PlatformStyle", "");
         qmlRegisterUncreatableType<Screen>(uri, 1, 0, "Screen", "");
-        qmlRegisterUncreatableType<WindowStack>(uri, 1, 0, "WindowStack", "");
+        qmlRegisterUncreatableType<PageStack>(uri, 1, 0, "PageStack", "");
     }
 }
 
@@ -96,6 +95,7 @@ void Plugin::registerTypes(const char *uri) {
     qRegisterMetaType<AnchorLine>("AnchorLine");
 
     qmlRegisterUncreatableType<QWidget>(uri, 1, 0, "Widget", "");
+    qmlRegisterUncreatableType<QAbstractButton>(uri, 1, 0, "AbstractButton", "");
 
     qmlRegisterType<Action>(uri, 1, 0, "Action");
     qmlRegisterType<ActionGroup>(uri, 1, 0, "ActionGroup");
@@ -129,6 +129,7 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<MouseArea>(uri, 1, 0, "MouseArea");
     qmlRegisterType<MouseDrag>(uri, 1, 0, "Drag");
     qmlRegisterType<MultiListSelector>(uri, 1, 0, "MultiListSelector");
+    qmlRegisterType<Page>(uri, 1, 0, "Page");
     qmlRegisterType<ProgressBar>(uri, 1, 0, "ProgressBar");
 //    qmlRegisterType<QDeclarativeComponent>(uri, 1, 0, "Component");
     qmlRegisterType<QDoubleValidator>(uri, 1, 0, "DoubleValidator");
