@@ -34,6 +34,10 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(int y READ y WRITE setY NOTIFY yChanged)
     Q_PROPERTY(int width READ width WRITE setFixedWidth NOTIFY widthChanged)
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
+    Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
+    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
+    Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged)
     Q_PRIVATE_PROPERTY(WebView::d_func(), Anchors* anchors READ anchors CONSTANT FINAL)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
@@ -41,13 +45,21 @@ class WebView : public QWebView, public QDeclarativeParserStatus
     Q_PROPERTY(AnchorLine bottom READ bottom CONSTANT FINAL)
     Q_PROPERTY(AnchorLine horizontalCenter READ horizontalCenter CONSTANT FINAL)
     Q_PROPERTY(AnchorLine verticalCenter READ verticalCenter CONSTANT FINAL)
-    Q_PROPERTY(QString icon READ iconSource)
+    Q_PROPERTY(QString icon READ iconSource NOTIFY iconChanged)
     Q_PROPERTY(bool textSelectionEnabled READ textSelectionEnabled WRITE setTextSelectionEnabled NOTIFY textSelectionEnabledChanged)
+    Q_PROPERTY(bool moving READ moving NOTIFY movingChanged)
+    Q_PROPERTY(bool atXBeginning READ atXBeginning NOTIFY contentXChanged)
+    Q_PROPERTY(bool atXEnd READ atXEnd NOTIFY contentXChanged)
+    Q_PROPERTY(bool atYBeginning READ atYBeginning NOTIFY contentYChanged)
+    Q_PROPERTY(bool atYEnd READ atYEnd NOTIFY contentYChanged)
+    Q_PROPERTY(int contentX READ contentX WRITE setContentX NOTIFY contentXChanged)
+    Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
     Q_PROPERTY(Status status READ status NOTIFY statusChanged)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> data READ data)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(WebView::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
-    Q_PRIVATE_PROPERTY(WebView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible)
+    Q_PRIVATE_PROPERTY(WebView::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
 
     Q_ENUMS(Status)
 
@@ -59,7 +71,7 @@ public:
     enum Status {
         Null = 0,
         Loading,
-        Finished,
+        Ready,
         Error
     };
 
@@ -69,6 +81,11 @@ public:
     void setX(int x);
     void setY(int y);
 
+    qreal opacity() const;
+    void setOpacity(qreal opacity);
+
+    void setFocus(bool focus);
+
     AnchorLine left() const;
     AnchorLine right() const;
     AnchorLine top() const;
@@ -81,6 +98,26 @@ public:
     bool textSelectionEnabled() const;
     void setTextSelectionEnabled(bool enabled);
 
+    bool moving() const;
+
+    bool atXBeginning() const;
+    bool atXEnd() const;
+
+    bool atYBeginning() const;
+    bool atYEnd() const;
+
+    int contentX() const;
+    void setContentX(int x);
+
+    int contentY() const;
+    void setContentY(int y);
+
+    qreal flickDeceleration() const;
+    void setFlickDeceleration(qreal deceleration);
+
+    qreal maximumFlickVelocity() const;
+    void setMaximumFlickVelocity(qreal maximum);
+
     int progress() const;
 
     Status status() const;
@@ -91,7 +128,17 @@ signals:
     void yChanged();
     void widthChanged();
     void heightChanged();
+    void opacityChanged();
+    void visibleChanged();
+    void focusChanged();
+    void titleChanged();
+    void urlChanged();
     void textSelectionEnabledChanged();
+    void movingChanged();
+    void contentXChanged();
+    void contentYChanged();
+    void flickDecelerationChanged();
+    void maximumFlickVelocityChanged();
     void progressChanged();
     void statusChanged();
 
@@ -101,6 +148,10 @@ private:
     void changeEvent(QEvent *event);
     void moveEvent(QMoveEvent *event);
     void resizeEvent(QResizeEvent *event);
+    void showEvent(QShowEvent *event);
+    void hideEvent(QHideEvent *event);
+    void focusInEvent(QFocusEvent *event);
+    void focusOutEvent(QFocusEvent *event);
 
     void classBegin();
     void componentComplete();
